@@ -33,10 +33,24 @@ class TVarFigureMap(pg.GraphicsLayout):
         self.yaxis = AxisItem("left")
         self.yaxis.setWidth(100)
 
+        # Creating axes to bound the plots with lines
+        self.xaxis2 = pg.AxisItem(orientation='top')
+        self.xaxis2.setHeight(0)
+        self.yaxis2 = AxisItem("right")
+        self.yaxis2.setWidth(0)
+
         vb = NoPaddingPlot()
-        self.plotwindow = self.addPlot(row=0, col=0, axisItems={'bottom': self.xaxis, 'left': self.yaxis}, viewBox=vb)
+        self.plotwindow = self.addPlot(row=0, col=0, axisItems={'bottom': self.xaxis,
+                                                                'left': self.yaxis,
+                                                                "right": self.yaxis2,
+                                                                "top": self.xaxis2}, viewBox=vb)
+
         self.plotwindow.vb.setLimits(xMin=0, xMax=360, yMin=-90, yMax=90)
 
+        if pytplot.data_quants[self.tvar_name].attrs['plot_options']['extras']['border']:
+            self.plotwindow.showAxis("top")
+            self.plotwindow.showAxis("right")
+
         # Set up the view box needed for the legends
         self.legendvb = pg.ViewBox(enableMouse=False)
         self.legendvb.setMaximumWidth(100)
